@@ -189,7 +189,7 @@ class DockerUtilsTest(unittest.TestCase):
                                                   labels_callee=return_callee("dummy_labels"))
             mock_docker_client.return_value.images.build.return_value = (
                 mock_docker_image,
-                {"dummy_key": "dummy_value"},
+                [{"dummy-log-key": "dummy-log-value"}],
             )
 
             image_model, build_logs = docker_build_image(mock_docker_client.return_value,
@@ -201,7 +201,7 @@ class DockerUtilsTest(unittest.TestCase):
             self.assertEqual(image_model.id, "dummy_image")
             self.assertEqual(image_model.tags, "dummy_tags")
             self.assertEqual(image_model.labels, "dummy_labels")
-            self.assertEqual(build_logs, {"dummy_key": "dummy_value"})
+            self.assertEqual(build_logs, [{"dummy-log-key": "dummy-log-value"}])
 
             mock_docker_client.return_value.images.build.assert_called_with(tag="dummy_tag",
                                                                             path="dummy_path",
@@ -212,7 +212,7 @@ class DockerUtilsTest(unittest.TestCase):
                                                                             nocache=True)
 
     @ddt.data(
-        (docker.errors.BuildError("dummy reason", iter([{"dummy-log-key": "dummy log"}])),),
+        (docker.errors.BuildError("dummy reason", iter([{"dummy-log-key": "dummy-log-value"}])),),
         (docker.errors.APIError("dummy message"),),
         (Exception(),),
     )
