@@ -6,7 +6,6 @@ from dataclasses import dataclass
 from typing import SupportsFloat, SupportsInt
 
 import ddt
-import pytest
 
 from iker.common.utils.jsonutils import asterisk, json_get, json_set
 from iker.common.utils.jsonutils import json_compare
@@ -957,7 +956,7 @@ class JsonUtilsTest(unittest.TestCase):
         ({"set": set(), "object": object()},),
     )
     def test_json_reformat__unregistered_type(self, data):
-        with pytest.raises(ValueError):
+        with self.assertRaises(ValueError):
             json_reformat(data)
 
     @ddt.data(
